@@ -1,5 +1,5 @@
 #!/bin/bash
-cargo build --release
+cargo build --bin ross-programmer-firmware --release
 
 if [ $? -ne 0 ]; then
     exit 1
